@@ -31,7 +31,8 @@ class TestCollections(unittest.TestCase):
             "OVERVIEW_TITLE": "",
             "OVERVIEW_TEMPLATE": "",
             "COLLECTION_TEMPLATE": "",
-            "SUMMARY_LENGTH": 100
+            "SUMMARY_LENGTH": 100,
+            "OVERVIEW_CONTENT": "",
         }
         col.config["COLLECTIONS"] = {"PRIORITY": 2}
         col.__init__()
@@ -105,6 +106,9 @@ class TestCollections(unittest.TestCase):
         result_2 = list(col.action(item=item_2.copy()))[0]
 
         collectible_1 = {
+            "destination": "web/page/page.html",
+            "extension": "md",
+            "origin": "./page/page.md",
             "title": "Test",
             "image": "dir/img.png",
             "date": "21.07.2021",
@@ -115,6 +119,9 @@ class TestCollections(unittest.TestCase):
             "timestamp": 2
         }
         collectible_2 = {
+            "destination": "web/page2/page2.html",
+            "extension": "md",
+            "origin": "./page2/page2.md",
             "title": "Test 2",
             "image": "dir/img.png",
             "date": "10.07.2021",
@@ -200,7 +207,7 @@ class TestCollections(unittest.TestCase):
                 "destination": os.path.join("web", "categories", "index.html"),
                 "meta": {
                     "title": "overview",
-                    "collections": [
+                    "collections_list": [
                         {
                             "name": "col2",
                             "size": 2,
@@ -225,7 +232,14 @@ class TestCollections(unittest.TestCase):
                 "extension": "md"
             }
         ]
-        actual_args = [list(args[0])[0] for args, kwargs in parse_meta.call_args_list]
+        actual_args = []
+        # actual_args = [list(args[0])[0] for args, kwargs in parse_meta.call_args_list]
+
+        for args, _ in parse_meta.call_args_list:
+            try:
+                actual_args.append(list(args[0])[0])
+            except IndexError:
+                pass
         self.assertCountEqual(golden_args, actual_args)
 
         del col.config["COLLECTIONS"]
